#[repr(C)]pub enum BufferSparseBinding {
None = 0,
Bound = 1,
Residency = 3,
Aliased = 5,
Both = 7,
}Expand description
Bitset specifying additional parameters of a buffer
Variants
None = 0
No sparse binding features
Bound = 1
the buffer will be backed using sparse memory binding
Residency = 3
the buffer can be partially backed using sparse memory binding.
Aliased = 5
the buffer will be backed using sparse memory binding with memory ranges that might also simultaneously be backing another buffer (or another portion of the same buffer)
Both = 7
Aliased and Residency