#[repr(u32)]pub enum ImageLayout {
Undefined = 0,
Preinitialized = 8,
General = 1,
ColorAttachmentOpt = 2,
DepthStencilAttachmentOpt = 3,
DepthStencilReadOnlyOpt = 4,
ShaderReadOnlyOpt = 5,
TransferSrcOpt = 6,
TransferDestOpt = 7,
PresentSrc = 1_000_001_002,
}Expand description
Layouts of image and image subresources
Variants
Undefined = 0
does not support device access
Preinitialized = 8
does not support device access. host can be written to this memory immediately
General = 1
supports all types of device access
ColorAttachmentOpt = 2
must only be used as a color or resolve attachment in a Framebuffer
DepthStencilAttachmentOpt = 3
must only be used as a depth/stencil attachment in a Framebuffer
DepthStencilReadOnlyOpt = 4
must only be used as a read-only depth/stencil attachment in a Framebuffer
and/or as a read-only image in a shader (which can be read as a sampled image,
combined image/sampler and/or input attachment).
ShaderReadOnlyOpt = 5
must only be used as a read-only image in a shader (which can be read as a sampled image, combined image/sampler and/or input attachment).
TransferSrcOpt = 6
must only be used as a source image of a transfer command
TransferDestOpt = 7
must only be used as a destination image of a transfer command
PresentSrc = 1_000_001_002
must only be used for presenting a swapchain image for display
Implementations
Sourceimpl ImageLayout
impl ImageLayout
Sourcepub fn default_access_mask(self) -> VkAccessFlags
pub fn default_access_mask(self) -> VkAccessFlags
Commonly used access types with the layout
Sourcepub const fn to(self, after: Self) -> LayoutTransition
pub const fn to(self, after: Self) -> LayoutTransition
Constructs the transition between image layouts.
Sourcepub const fn from(self, before: Self) -> LayoutTransition
pub const fn from(self, before: Self) -> LayoutTransition
Constructs the transition between image layouts (in reverse order).
Sourcepub const fn from_undefined(self) -> LayoutTransition
pub const fn from_undefined(self) -> LayoutTransition
Constructs the transition from undefined layout to this layout (convenient function).
Sourcepub const fn keep(self) -> LayoutTransition
pub const fn keep(self) -> LayoutTransition
Constructs the empty transition.