Struct AspectMask

pub struct AspectMask(/* private fields */);
Bitmask specifying which aspects of an image are included in a view

Implementations

Source

impl AspectMask

pub const fn bits(&self) -> VkImageAspectFlags

Returns bits in this flags

pub const fn has_any(self, other: Self) -> bool

Returns true if any of specified bits are contained in this flag.

pub const fn has_all(self, other: Self) -> bool

Returns true if all of specified bits are contained in this flag.

pub const fn merge(self, other: Self) -> Self

merge two flags (const alias of BitOr)

Source

impl AspectMask

pub const EMPTY: Self

No aspect mask

pub const COLOR: Self

The color aspect

pub const DEPTH: Self

The depth aspect

pub const STENCIL: Self

The stencil aspect

pub const METADATA: Self

The metadata aspect, used for sparse sparse resource operations