Struct BufferCreateInfo

pub struct BufferCreateInfo<'s>(/* private fields */);
Builder structure specifying the parameters of a newly created buffer object

Implementations

Source

impl<'s> BufferCreateInfo<'s>

pub const fn new(byte_size: usize, usage: BufferUsage) -> Self

Creates a new buffer description with provided byte-size and usage flags

pub const fn new_for_type<T>(usage: BufferUsage) -> Self

Creates a new buffer description which fits for a type

pub const unsafe fn from_raw(s: VkBufferCreateInfo) -> Self

Wraps raw vulkan structure

Safety

This function does not check any references/constraints

pub const unsafe fn into_raw(self) -> VkBufferCreateInfo

Unwraps raw vulkan structure

Safety

Lifetime constraints are removed

pub const fn sharing_queue_families(self, indices: &'s [u32]) -> Self

A list of queue families that will access this buffer

pub const fn sparse_binding_opt(self, opt: BufferSparseBinding) -> Self

A bitmask of BufferSparseBinding specifying additional parameters of the buffer

pub const fn with_usage(self, usage: BufferUsage) -> Self

Merges usage flags

pub const fn set_usage(self, usage: BufferUsage) -> Self

Overwrites usage flags

pub const fn size(&self) -> VkDeviceSize

pub const fn usage(&self) -> BufferUsage