Struct ImageFlags

pub struct ImageFlags(/* private fields */);
Bitmask specifying additional parameters of an image

Implementations

Source

impl ImageFlags

pub const fn bits(&self) -> VkImageCreateFlags

Returns bits in this flags

pub const fn has_any(self, other: Self) -> bool

Returns true if any of specified bits are contained in this flag.

pub const fn has_all(self, other: Self) -> bool

Returns true if all of specified bits are contained in this flag.

pub const fn merge(self, other: Self) -> Self

merge two flags (const alias of BitOr)

Source

impl ImageFlags

pub const EMPTY: Self

Empty bits

pub const SPARSE_BINDING: Self

The image will be backed using sparse memory binding

pub const SPARSE_RESIDENCY: Self

The image can be partially backed using sparse memory binding. This bit is with SPARSE_BINDING implicitly

pub const SPARSE_ALIASED: Self

The image will be backed using sparse memory binding with memory ranges that might also simultaneously be backing another image. This bit is with SPARSE_BINDING implicitly

pub const MUTABLE_FORMAT: Self

The image can be used to create a ImageView with a different format from the image

pub const CUBE_COMPATIBLE: Self

The image can be used to create a ImageView of type ImageViewType::Cube or ImageViewType::CubeArray