Struct ImageUsageFlags

pub struct ImageUsageFlags(/* private fields */);
Bitmask specifying intended usage of an image.

Implementations

Source

impl ImageUsageFlags

pub const fn bits(&self) -> VkImageUsageFlags

Returns bits in this flags

pub const fn has_any(self, other: Self) -> bool

Returns true if any of specified bits are contained in this flag.

pub const fn has_all(self, other: Self) -> bool

Returns true if all of specified bits are contained in this flag.

pub const fn merge(self, other: Self) -> Self

merge two flags (const alias of BitOr)

Source

impl ImageUsageFlags

pub const TRANSFER_SRC: Self

The image can be used as the source of a transfer command

pub const TRANSFER_DEST: Self

The image can be used as the destination of a transfer command

pub const SAMPLED: Self

The image can be used to create ImageView suitable for occupying a DescriptorSet slot either of type DescriptorType::SampledImage or DescriptorType::CombinedImageSampler, and be sampled by a shader

pub const STORAGE: Self

The image can be used to create a ImageView suitable for occupying a DescriptorSet slot of type DescriptorType::StorageImage

pub const COLOR_ATTACHMENT: Self

The image can be used to create a ImageView suitable for use as a color or resolve attachment in a Framebuffer

pub const DEPTH_STENCIL_ATTACHMENT: Self

The image can be used to create a ImageView suitable for use as a depth/stencil attachment in a Framebuffer

pub const TRANSIENT_ATTACHMENT: Self

The memory bound to this image will have been allocated with the VK_MEMORY_PROPERTY_LAZILY_ALLOCATED_BIT This bit can be set for any image that can be used to create a ImageView suitable for use as a color, resolve, depth/stencil, or input attachment

pub const INPUT_ATTACHMENT: Self

The image can be used to create a ImageView suitable for occupying DescriptorSet slot of type DescriptorType::InputAttachment; be read from a shader as an input attachment; and be used as an input attachment in a framebuffer