Struct MappedMemory

pub struct MappedMemory<'m, DeviceMemory: DeviceMemoryMut + ?Sized + 'm>(/* private fields */);
Specifies the block of mapped memory in a DeviceMemory

Implementations

Source

impl<'m, DeviceMemory: DeviceMemoryMut + ?Sized + 'm> MappedMemory<'m, DeviceMemory>

pub const fn ptr(&self) -> *mut c_void

Returns a pointer to the head of the mapped region

pub const unsafe fn addr_of_mut<T>(&self, offset: usize) -> *mut T

Get a mutable pointer in mapped memory with byte offsets

Safety

Caller must guarantee that the pointer and its alignment are valid

pub const unsafe fn get<T>(&self, offset: usize) -> &T

Get a reference in mapped memory with byte offsets

Safety

Caller must guarantee that the pointer and its alignment are valid

pub const unsafe fn get_mut<T>(&self, offset: usize) -> &mut T

Get a mutable reference in mapped memory with byte offsets

Safety

Caller must guarantee that the pointer and its alignment are valid

pub const unsafe fn slice<T>(&self, offset: usize, count: usize) -> &[T]

Get a slice in mapped memory with byte offsets

Safety

Caller must guarantee that the pointer and its alignment are valid

pub const unsafe fn slice_mut<T>(&self, offset: usize, count: usize) -> &mut [T]

Get a mutable slice in mapped memory with byte offsets

Safety

Caller must guarantee that the pointer and its alignment are valid

pub unsafe fn clone_from_slice_at<T: Clone>(&self, offset: usize, src: &[T])

Clone data from slice at the specified offset in mapped memory.

Safety

Caller must guarantee that the pointer and its alignment are valid

pub unsafe fn clone_at<T: Clone>(&self, offset: usize, src: &T)

Clone data from slice at the specified offset in mapped memory.

Safety

Caller must guarantee that the pointer and its alignment are valid

pub fn end(self)

Unmap region