pub struct AspectMask(/* private fields */);Expand description
Bitmask specifying which aspects of an image are included in a view
Implementations
Sourceimpl AspectMask
impl AspectMask
Sourcepub const fn bits(&self) -> VkImageAspectFlags
pub const fn bits(&self) -> VkImageAspectFlags
Returns bits in this flags
Sourcepub const fn has_any(self, other: Self) -> bool
pub const fn has_any(self, other: Self) -> bool
Returns true if any of specified bits are contained in this flag.