pub struct BufferCreateInfo<'s>(/* private fields */);Expand description
Builder structure specifying the parameters of a newly created buffer object
Implementations
Sourceimpl<'s> BufferCreateInfo<'s>
impl<'s> BufferCreateInfo<'s>
Sourcepub const fn new(byte_size: usize, usage: BufferUsage) -> Self
pub const fn new(byte_size: usize, usage: BufferUsage) -> Self
Creates a new buffer description with provided byte-size and usage flags
Sourcepub const fn new_for_type<T>(usage: BufferUsage) -> Self
pub const fn new_for_type<T>(usage: BufferUsage) -> Self
Creates a new buffer description which fits for a type
Sourcepub const unsafe fn from_raw(s: VkBufferCreateInfo) -> Self
pub const unsafe fn from_raw(s: VkBufferCreateInfo) -> Self
Sourcepub const unsafe fn into_raw(self) -> VkBufferCreateInfo
pub const unsafe fn into_raw(self) -> VkBufferCreateInfo
Sourcepub const fn sharing_queue_families(self, indices: &'s [u32]) -> Self
pub const fn sharing_queue_families(self, indices: &'s [u32]) -> Self
A list of queue families that will access this buffer
Sourcepub const fn sparse_binding_opt(self, opt: BufferSparseBinding) -> Self
pub const fn sparse_binding_opt(self, opt: BufferSparseBinding) -> Self
A bitmask of BufferSparseBinding specifying additional parameters of the buffer
Sourcepub const fn with_usage(self, usage: BufferUsage) -> Self
pub const fn with_usage(self, usage: BufferUsage) -> Self
Merges usage flags
Sourcepub const fn set_usage(self, usage: BufferUsage) -> Self
pub const fn set_usage(self, usage: BufferUsage) -> Self
Overwrites usage flags
pub const fn size(&self) -> VkDeviceSize
pub const fn usage(&self) -> BufferUsage