#[repr(transparent)]pub struct BufferUsage(pub VkBufferUsageFlags);Expand description
Bitmask specifying allowed usage of a buffer
Tuple Fields
0: VkBufferUsageFlagsImplementations
Sourceimpl BufferUsage
impl BufferUsage
Sourcepub const TRANSFER_SRC: Self
pub const TRANSFER_SRC: Self
Specifies that the buffer can be used as the source of a transfer command
Sourcepub const TRANSFER_DEST: Self
pub const TRANSFER_DEST: Self
Specifies that the buffer can be used as the destination of a transfer command
Sourcepub const UNIFORM_TEXEL_BUFFER: Self
pub const UNIFORM_TEXEL_BUFFER: Self
Specifies that the buffer can be used to create a BufferView suitable for
occupying a DescriptorSet slot of type VK_DESCRIPTOR_TYPE_UNIFORM_TEXEL_BUFFER
Sourcepub const STORAGE_TEXEL_BUFFER: Self
pub const STORAGE_TEXEL_BUFFER: Self
Specifies that the buffer can be used to create a BufferView suitable for
occupying a DescriptorSet slot of type VK_DESCRIPTOR_TYPE_STORAGE_TEXEL_BUFFER
Sourcepub const UNIFORM_BUFFER: Self
pub const UNIFORM_BUFFER: Self
Specifies that the buffer can be used in a DescriptorBufferInfo suitable for
occupying a DescriptorSet slot either of type VK_DESCRIPTOR_TYPE_UNIFORM_BUFFER or VK_DESCRIPTOR_TYPE_UNIFORM_BUFFER_DYNAMIC
Sourcepub const STORAGE_BUFFER: Self
pub const STORAGE_BUFFER: Self
Specifies that the buffer can be used in a DescriptorBufferInfo suitable for
occupying a DescriptorSet slot either of type VK_DESCRIPTOR_TYPE_STORAGE_BUFFER or VK_DESCRIPTOR_TYPE_STORAGE_BUFFER_DYNAMIC
Sourcepub const INDEX_BUFFER: Self
pub const INDEX_BUFFER: Self
Specifies that the buffer is suitable for passing as the buffer parameter to DrawCommandBuffer::bind_index_buffer
Sourcepub const VERTEX_BUFFER: Self
pub const VERTEX_BUFFER: Self
Specifies that the buffer is suitable for passing as an element of the buffers array to DrawCommandBuffer::bind_vertex_buffers
Sourcepub const INDIRECT_BUFFER: Self
pub const INDIRECT_BUFFER: Self
Specifies that the buffer is suitable for passing as the buffer parameter to
DrawCommandBuffer::draw_indirect, DrawCommandBuffer::draw_indexed_indirect, or ComputeCommandBuffer::dispatch_indirect
Sourcepub const fn transfer_src(self) -> Self
pub const fn transfer_src(self) -> Self
Specifies that the buffer can be used as the source of a transfer command
Sourcepub const fn transfer_dest(self) -> Self
pub const fn transfer_dest(self) -> Self
Specifies that the buffer can be used as the destination of a transfer command
Sourcepub const fn uniform_texel_buffer(self) -> Self
pub const fn uniform_texel_buffer(self) -> Self
Specifies that the buffer can be used to create a BufferView suitable for
occupying a DescriptorSet slot of type VK_DESCRIPTOR_TYPE_UNIFORM_TEXEL_BUFFER
Sourcepub const fn storage_texel_buffer(self) -> Self
pub const fn storage_texel_buffer(self) -> Self
Specifies that the buffer can be used to create a BufferView suitable for
occupying a DescriptorSet slot of type VK_DESCRIPTOR_TYPE_STORAGE_TEXEL_BUFFER
Sourcepub const fn uniform_buffer(self) -> Self
pub const fn uniform_buffer(self) -> Self
Specifies that the buffer can be used in a DescriptorBufferInfo suitable for
occupying a DescriptorSet slot either of type VK_DESCRIPTOR_TYPE_UNIFORM_BUFFER or VK_DESCRIPTOR_TYPE_UNIFORM_BUFFER_DYNAMIC
Sourcepub const fn storage_buffer(self) -> Self
pub const fn storage_buffer(self) -> Self
Specifies that the buffer can be used in a DescriptorBufferInfo suitable for
occupying a DescriptorSet slot either of type VK_DESCRIPTOR_TYPE_STORAGE_BUFFER or VK_DESCRIPTOR_TYPE_STORAGE_BUFFER_DYNAMIC
Sourcepub const fn index_buffer(self) -> Self
pub const fn index_buffer(self) -> Self
Specifies that the buffer is suitable for passing as the buffer parameter to DrawCommandBuffer::bind_index_buffer
Sourcepub const fn vertex_buffer(self) -> Self
pub const fn vertex_buffer(self) -> Self
Specifies that the buffer is suitable for passing as an element of the buffers array to DrawCommandBuffer::bind_vertex_buffers
Sourcepub const fn indirect_buffer(self) -> Self
pub const fn indirect_buffer(self) -> Self
Specifies that the buffer is suitable for passing as the buffer parameter to
DrawCommandBuffer::draw_indirect, DrawCommandBuffer::draw_indexed_indirect, or ComputeCommandBuffer::dispatch_indirect
Sourcepub const fn default_access_mask(self) -> VkAccessFlags
pub const fn default_access_mask(self) -> VkAccessFlags
Generates a default access type mask
Sourcepub const fn is_uniform(self) -> bool
pub const fn is_uniform(self) -> bool
Determines if flag contains usage of uniform-buffer
Sourcepub const fn is_storage(self) -> bool
pub const fn is_storage(self) -> bool
Determines if flag contains usage of storage-buffer