pub struct ImageCreateInfo<'d>(/* private fields */);Implementations
Sourceimpl<'d> ImageCreateInfo<'d>
impl<'d> ImageCreateInfo<'d>
pub fn new<Size: ImageSize>(size: Size, format: VkFormat) -> Self
pub const unsafe fn from_raw(raw: VkImageCreateInfo) -> Self
pub const fn into_raw(self) -> VkImageCreateInfo
pub fn with_next(self, next: &'d (impl TypedVulkanStructure + ?Sized)) -> Self
Sourcepub fn size<Size: ImageSize>(self, size: Size) -> Self
pub fn size<Size: ImageSize>(self, size: Size) -> Self
Sets an size and a dimension of the created image.
Sourcepub const fn init_layout(self, layout: ImageLayout) -> Self
pub const fn init_layout(self, layout: ImageLayout) -> Self
Sets an initial layout for the created image. default: Undefined layout
Sourcepub const fn sharing_queue_families(self, indices: &'d [u32]) -> Self
pub const fn sharing_queue_families(self, indices: &'d [u32]) -> Self
A list of queue families that will access this image, or an empty list if no queue families can access this image simultaneously
Sourcepub const fn sample_counts(self, count_bits: u32) -> Self
pub const fn sample_counts(self, count_bits: u32) -> Self
The number of sub-data element samples in the image bitmask of 1(default), 2, 4, 8, 16, 32, 64
Sourcepub const fn use_linear_tiling(self) -> Self
pub const fn use_linear_tiling(self) -> Self
Sets the tiling arrangement of the data elements in memory as “linear tiling” default: optimal tiling
Sourcepub const fn flags(self, opt: ImageFlags) -> Self
pub const fn flags(self, opt: ImageFlags) -> Self
A bitmask of ImageFlagsdescribing additional parameters of the image
default: none
Sourcepub const fn array_layers(self, layers: u32) -> Self
pub const fn array_layers(self, layers: u32) -> Self
The number of layers in the image default: 1
Sourcepub const fn mip_levels(self, levels: u32) -> Self
pub const fn mip_levels(self, levels: u32) -> Self
The number of levels of detail available for minified sampling of the image default: 1
Sourcepub const fn with_usage(self, bits: ImageUsageFlags) -> Self
pub const fn with_usage(self, bits: ImageUsageFlags) -> Self
Merges some custom usage flag bits.
Sourcepub const fn set_usage(self, bits: ImageUsageFlags) -> Self
pub const fn set_usage(self, bits: ImageUsageFlags) -> Self
Overwrites all of custom usage flag bits.