pub struct ImageFlags(/* private fields */);Expand description
Bitmask specifying additional parameters of an image
Implementations
Sourceimpl ImageFlags
impl ImageFlags
Sourcepub const fn bits(&self) -> VkImageCreateFlags
pub const fn bits(&self) -> VkImageCreateFlags
Returns bits in this flags
Sourcepub const fn has_any(self, other: Self) -> bool
pub const fn has_any(self, other: Self) -> bool
Returns true if any of specified bits are contained in this flag.
Sourceimpl ImageFlags
impl ImageFlags
Sourcepub const SPARSE_BINDING: Self
pub const SPARSE_BINDING: Self
The image will be backed using sparse memory binding
Sourcepub const SPARSE_RESIDENCY: Self
pub const SPARSE_RESIDENCY: Self
The image can be partially backed using sparse memory binding. This bit is with SPARSE_BINDING implicitly
Sourcepub const SPARSE_ALIASED: Self
pub const SPARSE_ALIASED: Self
The image will be backed using sparse memory binding with memory ranges
that might also simultaneously be backing another image. This bit is with SPARSE_BINDING implicitly
Sourcepub const MUTABLE_FORMAT: Self
pub const MUTABLE_FORMAT: Self
The image can be used to create a ImageView with a different format from the image
Sourcepub const CUBE_COMPATIBLE: Self
pub const CUBE_COMPATIBLE: Self
The image can be used to create a ImageView of type ImageViewType::Cube or ImageViewType::CubeArray