pub struct ImageUsageFlags(/* private fields */);Expand description
Bitmask specifying intended usage of an image.
Implementations
Sourceimpl ImageUsageFlags
impl ImageUsageFlags
Sourcepub const fn bits(&self) -> VkImageUsageFlags
pub const fn bits(&self) -> VkImageUsageFlags
Returns bits in this flags
Sourcepub const fn has_any(self, other: Self) -> bool
pub const fn has_any(self, other: Self) -> bool
Returns true if any of specified bits are contained in this flag.
Sourceimpl ImageUsageFlags
impl ImageUsageFlags
Sourcepub const TRANSFER_SRC: Self
pub const TRANSFER_SRC: Self
The image can be used as the source of a transfer command
Sourcepub const TRANSFER_DEST: Self
pub const TRANSFER_DEST: Self
The image can be used as the destination of a transfer command
Sourcepub const SAMPLED: Self
pub const SAMPLED: Self
The image can be used to create ImageView suitable for occupying a DescriptorSet slot
either of type DescriptorType::SampledImage or DescriptorType::CombinedImageSampler, and be sampled by a shader
Sourcepub const STORAGE: Self
pub const STORAGE: Self
The image can be used to create a ImageView suitable for occupying a DescriptorSet slot of type DescriptorType::StorageImage
Sourcepub const COLOR_ATTACHMENT: Self
pub const COLOR_ATTACHMENT: Self
The image can be used to create a ImageView suitable for use as a color or resolve attachment in a Framebuffer
Sourcepub const DEPTH_STENCIL_ATTACHMENT: Self
pub const DEPTH_STENCIL_ATTACHMENT: Self
The image can be used to create a ImageView suitable for use as a depth/stencil attachment in a Framebuffer
Sourcepub const TRANSIENT_ATTACHMENT: Self
pub const TRANSIENT_ATTACHMENT: Self
The memory bound to this image will have been allocated with the VK_MEMORY_PROPERTY_LAZILY_ALLOCATED_BIT
This bit can be set for any image that can be used to create a ImageView suitable for use as a color, resolve, depth/stencil,
or input attachment
Sourcepub const INPUT_ATTACHMENT: Self
pub const INPUT_ATTACHMENT: Self
The image can be used to create a ImageView suitable for occupying DescriptorSet slot of type DescriptorType::InputAttachment;
be read from a shader as an input attachment; and be used as an input attachment in a framebuffer